@@ -2,7 +2,7 @@
 #     Project: PyOdoo
 # Description: API for Odoo
 #      Author: Fabio Castelli (Muflone) <muflone@muflone.com>
-#   Copyright: 2021 Fabio Castelli
+#   Copyright: 2021-2022 Fabio Castelli
 #     License: GPL-3+
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -21,4 +21,6 @@
 from .active_status_choice import ActiveStatusChoice               # noqa: F401
 from .boolean_operator import BooleanOperator                      # noqa: F401
 from .compare_type import CompareType                              # noqa: F401
+from .constants import APP_VERSION as __version__                  # noqa: F401
 from .filter import Filter                                         # noqa: F401
+from .message_subtype import MessageSubType                        # noqa: F401
