@@ -19,13 +19,13 @@
 ##
 
 APP_NAME = 'PyOdoo'
-APP_VERSION = '0.5.0'
+APP_VERSION = '0.5.1'
 APP_DESCRIPTION = 'API for Odoo'
 APP_DOMAIN = 'pyodoo'
 APP_ID = f'{APP_DOMAIN}.muflone.com'
 APP_AUTHOR = 'Fabio Castelli'
 APP_AUTHOR_EMAIL = 'muflone@muflone.com'
 APP_COPYRIGHT = f'Copyright 2021-2022 {APP_AUTHOR}'
-URL_AUTHOR = 'https://www.muflone.com/'
+URL_AUTHOR = 'http://www.muflone.com/'
 URL_APPLICATION = f'{URL_AUTHOR}{APP_DOMAIN}/'
 URL_SOURCES = f'https://github.com/muflone/{APP_DOMAIN}/'
